==> thrift_http_tornado-0.0.3.tar.gz: thrift_http_tornado-0.0.3/thrift_http_tornado/transport.py <==
import cStringIO
import logging

import toro
import thrift.transport.TTransport
import tornado.gen
import tornado.ioloop
import tornado.httpclient

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)


class THTTPTornadoTransport(thrift.transport.TTransport.TTransportBase):
    def __init__(self, endpoint_url='http://localhost:8989',
                 io_loop=None, *args, **kwargs):
        self._client = tornado.httpclient.AsyncHTTPClient()
        self._wbuf = cStringIO.StringIO()
        self.io_loop = io_loop or tornado.ioloop.IOLoop.instance()
        self._endpoint = endpoint_url
        self._response_queue = toro.Queue(io_loop=self.io_loop)
        self._kwargs = kwargs
        self._headers = {'Content-Type': 'application/x-thrift'}

    def open(self, *args, **kwargs):
        pass

    @tornado.gen.coroutine
    def readFrame(self):
        result = yield self._response_queue.get()
        raise tornado.gen.Return(result)

    def close(self):
        pass

    def isOpen(self):
        return True

    def read(self, _):
        assert False, "wrong stuff"

    def write(self, buf):
        self._wbuf.write(buf)

    @tornado.gen.coroutine
    def flush(self):
        self.fetch(self._wbuf.getvalue())
        self._wbuf = cStringIO.StringIO()

    @tornado.gen.coroutine
    def fetch(self, buf):
        request = tornado.httpclient.HTTPRequest(url=self._endpoint,
                                                 method="POST", body=buf)
        r = yield self._client.fetch(request, self._kwargs,
                                     headers=self._headers)

        self._response_queue.put(r.body)

==> thrift_http_tornado-0.0.4.tar.gz: thrift_http_tornado-0.0.4/thrift_http_tornado/transport.py <==
import cStringIO
import logging

import toro
import thrift.transport.TTransport
import tornado.gen
import tornado.ioloop
import tornado.httpclient

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)


class THTTPTornadoTransport(thrift.transport.TTransport.TTransportBase):
    def __init__(self, endpoint_url='http://localhost:8989',
                 io_loop=None, *args, **kwargs):
        self._client = tornado.httpclient.AsyncHTTPClient()
        self._wbuf = cStringIO.StringIO()
        self.io_loop = io_loop or tornado.ioloop.IOLoop.instance()
        self._endpoint = endpoint_url
        self._response_queue = toro.Queue(io_loop=self.io_loop)
        self._kwargs = kwargs
        self._headers = {'Content-Type': 'application/x-thrift'}

    def open(self, *args, **kwargs):
        pass

    @tornado.gen.coroutine
    def readFrame(self):
        result = yield self._response_queue.get()
        raise tornado.gen.Return(result)

    def close(self):
        pass

    def isOpen(self):
        return True

    def read(self, _):
        assert False, "wrong stuff"

    def write(self, buf):
        self._wbuf.write(buf)

    @tornado.gen.coroutine
    def flush(self):
        self.fetch(self._wbuf.getvalue())
        self._wbuf = cStringIO.StringIO()

    @tornado.gen.coroutine
    def fetch(self, buf):
        request = tornado.httpclient.HTTPRequest(url=self._endpoint,
                                                 headers=self._headers,
                                                 method="POST", body=buf)
        r = yield self._client.fetch(request, self._kwargs)

        self._response_queue.put(r.body)
